# -*- coding: utf-8 -*-
# Copyright (C) 2004-2008 Tristan Seligmann and Jonathan Jacobs
# Copyright (C) 2012-2014 Bastian Kleineidam
# Copyright (C) 2015-2020 Tobias Gruetzmacher

from __future__ import absolute_import, division, print_function

from ..scraper import _ParserScraper


class ComicSherpa(_ParserScraper):
    url = 'http://www.comicssherpa.com/site/'
    imageSearch = '//img[contains(@src, "/comics/")]'
    prevSearch = '//a[text()="previous day"]'
    help = 'Index format: yyyymmdd'

    def __init__(self, name, path):
        super(ComicSherpa, self).__init__('ComicSherpa/' + name)
        self.session.add_throttle('www.comicssherpa.com', 1.0, 2.0)
        self.url = 'http://www.comicssherpa.com/site/feature?uc_comic=' + path

    def getIndexStripUrl(self, index):
        return self.url + '&uc_full_date=%s' % index

    @classmethod
    def getmodules(cls):
        return (
            # do not edit anything below since these entries are generated from
            # scripts/comicsherpa.py
            # START AUTOUPDATE
            cls('060', 'csadl'),
            cls('AaronGuile', 'csdsf'),
            cls('ABCStreet', 'csmbx'),
            cls('ABitSketch', 'csxmy'),
            cls('ABomb', 'csvur'),
            cls('ACMEINKD', 'csmwt'),
            cls('AcornPark', 'csdfe'),
            cls('Adulting', 'cskky'),
            cls('AllInGoodTime', 'csjhr'),
            cls('AmandaTheGreat', 'cssyr'),
            cls('AndNow', 'csnxr'),
            cls('Anecdote', 'cspmf'),
            cls('AnimalMitchell', 'csdnm'),
            cls('AnneAndPythagoras', 'csokq'),
            cls('AppleCreekComics', 'cstgq'),
            cls('ATasteOfTimes', 'csprn'),
            cls('BatchRejection', 'csgny'),
            cls('Bazoobee', 'csfos'),
            cls('BeMisery', 'csiiq'),
            cls('BigJim', 'csiao'),
            cls('Bluebonnets', 'cston'),
            cls('BlueSkiesToons', 'csfoy'),
            cls('BobsYourUncle', 'csmxz'),
            cls('BoltsAndNuts', 'csnab'),
            cls('Bork', 'csczn'),
            cls('BottAuto', 'csmwz'),
            cls('BUNS', 'csbft'),
            cls('Bushscrubs', 'csmzx'),
            cls('CAFFEINATED', 'csbmv'),
            cls('CandacenCompany', 'csvpd'),
            cls('CarteBlanche', 'csnwk'),
            cls('CharmysArmy', 'cswrl'),
            cls('Complex', 'csusy'),
            cls('CourageousManAdventures', 'csgkn'),
            cls('DadsDay', 'cswly'),
            cls('DBCartoons', 'csnvt'),
            cls('DoghouseInYourSoul', 'cstwx'),
            cls('DoingTime', 'csvuk'),
            cls('DontPickTheFlowers', 'cswfs'),
            cls('Dragin', 'cswgz'),
            cls('DumbQuestionBadAnswer', 'cskro'),
            cls('DungeonHordes', 'csnlo'),
            cls('DustSpecks', 'csqgq'),
            cls('DutchnPals', 'cskqc'),
            cls('Econogirl', 'csxoj'),
            cls('EightballEyeball', 'csnfh'),
            cls('Elmo', 'csvff'),
            cls('Endangered', 'cshii'),
            cls('FamousAndNotSoFamousQuotes', 'csdgz'),
            cls('FarOut', 'csaem'),
            cls('FatherOfTheBrood', 'csuul'),
            cls('FoxTheCat', 'csxbc'),
            cls('FrankAndSteinway', 'cseui'),
            cls('FriedCritter', 'cshtp'),
            cls('GarciaCartoonCo', 'csyuw'),
            cls('GIRTH', 'csbjw'),
            cls('GrandmaSnoops', 'csscq'),
            cls('GrannyAnny', 'cskpg'),
            cls('GreenPieces', 'csnwy'),
            cls('GunstonStreet', 'csgru'),
            cls('HallEditorialCartoons', 'csgzx'),
            cls('HaphazardHumor', 'cspsa'),
            cls('Headcheese', 'cspku'),
            cls('Hogwashed', 'csbnf'),
            cls('HomeLife', 'csrbv'),
            cls('Hubbel', 'cszrr'),
            cls('HugoComics', 'csdwl'),
            cls('HurrieTheMisManager', 'cssri'),
            cls('HuskyTales', 'cslnp'),
            cls('InkwellForest', 'csmuk'),
            cls('IronyOr', 'csddz'),
            cls('ItsJustJim', 'cszos'),
            cls('JolleyStuffBrowser', 'csjpq'),
            cls('KALEECHIKORNERS', 'cshdw'),
            cls('KartoonsByKline', 'csoei'),
            cls('LaffToons', 'cssvj'),
            cls('LiliAndDerek', 'csvsy'),
            cls('LilleysSillies', 'cstka'),
            cls('LimboRoad', 'csfpp'),
            cls('LumAndAbner', 'cscji'),
            cls('MarysNature', 'csogt'),
            cls('Millennialville', 'csxrl'),
            cls('Milton50', 'csmof'),
            cls('Mindframe', 'csqnp'),
            cls('Minihahas', 'csoat'),
            cls('MiscSoup', 'csguq'),
            cls('MisterAndMe', 'csvhr'),
            cls('MockAll', 'csrds'),
            cls('Moments', 'csnso'),
            cls('Mongrels', 'csbjo'),
            cls('MortsIsland', 'csfyq'),
            cls('MySonIsADog', 'csfec'),
            cls('NoAmbiguity', 'csryw'),
            cls('NoBusinessIKnow', 'csmfg'),
            cls('NoOrdinaryLife', 'csicr'),
            cls('Npchumorcom', 'csbuv'),
            cls('OneFunnyGoldenRetriever', 'csnrf'),
            cls('ONIONAndPEA', 'cstsr'),
            cls('OscarAndAnnie', 'csczw'),
            cls('OverQuirked', 'cspes'),
            cls('PaddedCell', 'csxqk'),
            cls('Painterly', 'csuya'),
            cls('PalAndBuddy', 'csjut'),
            cls('PawsForThoughtComics', 'csced'),
            cls('Peeples', 'csnkd'),
            cls('PeopleOfEarth', 'csjqa'),
            cls('PicpakDog', 'cstmm'),
            cls('PirateMike', 'csxcb'),
            cls('PoliceLimit', 'cspcc'),
            cls('PoliticularJokesAndRuffus', 'csmvz'),
            cls('Prideland', 'csaoa'),
            cls('PrimusTheBadPhilosopher', 'csofd'),
            cls('ProfessorHerbertAndGEO', 'cscje'),
            cls('QueenBlackbeard', 'csecq'),
            cls('QuickDraw', 'csydp'),
            cls('RandysRationale', 'cshsw'),
            cls('Ringers', 'csxhx'),
            cls('RonWarren', 'csuwd'),
            cls('SandSharkBeach', 'cssqk'),
            cls('SharpCurveComics', 'csyek'),
            cls('SherpaAid', 'csvku'),
            cls('SignGarden', 'csbxu'),
            cls('SignsOfAFrustratedGolfer', 'csxdy'),
            cls('Skull', 'csdxo'),
            cls('Skylarking', 'csyac'),
            cls('SleepytownBeagles', 'cssbk'),
            cls('SmallNerdyCreatures', 'cshqb'),
            cls('Smith', 'csmdx'),
            cls('Snootle', 'cseic'),
            cls('SoccerDude', 'csnnb'),
            cls('SoccerEarth', 'csdma'),
            cls('SOD', 'cszdh'),
            cls('SomethingAboutCeleste', 'csgtv'),
            cls('SookyRottweiler', 'csegu'),
            cls('Spaceport51', 'csbyh'),
            cls('SportsByVoort', 'cskin'),
            cls('StaleCrackers', 'csngu'),
            cls('StankoAndTibor', 'csurl'),
            cls('Strangeville', 'cskps'),
            cls('SubSub', 'csvcv'),
            cls('SuburbanFairyTales', 'cscek'),
            cls('SUITSANDGUARDERS', 'cssag'),
            cls('SuperSiblings', 'csdxj'),
            cls('TheBeauforts', 'csfxu'),
            cls('TheBellies', 'csubt'),
            cls('TheBoobiehatch', 'csoev'),
            cls('TheCardinal', 'csfjg'),
            cls('TheDinkledorfs', 'cszhp'),
            cls('TheFabulousBushPigs', 'cscqi'),
            cls('TheGrayZone', 'csmue'),
            cls('TheGreenMonkeys', 'cscue'),
            cls('TheMagicForest', 'csjts'),
            cls('TheMothManAndLarvaeBoy', 'csycu'),
            cls('TheMountainMen', 'cskqw'),
            cls('TheNeighborhood', 'csrtu'),
            cls('TheNevilleYouKnow', 'csnov'),
            cls('TheNonsenseNewz', 'csghu'),
            cls('TheOldManAndHisDog', 'csudu'),
            cls('TheQuinnAndFinnShow', 'csynn'),
            cls('TheRocks', 'cswky'),
            cls('TheUnemployed', 'csanx'),
            cls('Thingsesque', 'cstsq'),
            cls('TodaysTrump', 'csbrj'),
            cls('TopicToons', 'csgly'),
            cls('ToughTown', 'csnjp'),
            cls('ToxicValues', 'csyig'),
            cls('TruthBeKnown', 'csfwi'),
            cls('TuesdaysWithCory', 'csiea'),
            cls('Underdone', 'csayl'),
            cls('UnMannerlyWays', 'csjmh'),
            cls('ViewFromTheCouch', 'csipm'),
            cls('VoicesInTheDark', 'csyou'),
            cls('WarpedAndDemented', 'csbgw'),
            cls('Waskataskahiskewaskewan', 'cssfg'),
            cls('WayOutComics', 'cstrs'),
            cls('WeaselInk', 'csfsn'),
            cls('WhiskeyFalls', 'csitw'),
            cls('Windsock', 'csywy'),
            cls('WrobbertCartoons', 'csupg'),
            cls('YinYangster', 'csteo'),
            cls('ZombieHeights', 'cswjq'),
            cls('Zootopia', 'csquz'),
            # END AUTOUPDATE
        )
